/***************************************************************************
 *   Copyright (C) 2008 by Alexey Noskov   *
 *   alexey.noskov@gmail.com   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef KOPETEANTISPAMPLUGIN_H
#define KOPETEANTISPAMPLUGIN_H

#include <kopete/kopeteplugin.h>
#include <kopete/kopetemessage.h>

#include <qstring.h>
#include <qfile.h>
#include <qtimer.h>
#include <qprocess.h>
#include <qregexp.h>
#include <qvariant.h>

#include <vector>

namespace Kopete {

class Contact;
class MetaContact;

}

/**
 * @author Noskov Alexey
 *
 * @short Kopete Antispam Plugin.
 */
class KopeteAntispamPlugin : public Kopete::Plugin
{
	Q_OBJECT
public:
	KopeteAntispamPlugin( QObject *parent, const QVariantList & args );

protected slots:

	/**
	 * @short Handles initialization of plugin
	 */
	void init();

	/**
	 * @short Re-read plugin configuration and immediately apply changes.
	 */
	void settingsChanged();

	/**
	 * @short Handles message receiving
	 */
	void onMessageReceive( Kopete::Message & msg );

	void removeSessionContacts();
private:
	typedef std::vector<QRegExp> QRegExpList;
private:
	/**
	 * Checks if contact is in white list
	 */
	bool contactInWhiteList( const Kopete::Contact * contact );

	bool contactInList( const Kopete::Contact * contact );

	void removeContact( Kopete::Contact * contact );

	void updateRegExpList( QRegExpList & list, const QString & str );

	bool stringInRegExpList( const QRegExpList & list, const QString & str );
private:
	bool ignoreUnknown;
	bool removeSpammers;

	QString question;

	QString passMessage;

	QRegExpList answers;

	QRegExpList whiteList;

	static KopeteAntispamPlugin *instance;
};

#endif // KOPETEANTISPAMPLUGIN_H
